@@ -19,7 +19,7 @@ from sentry_sdk.integrations._asgi_common import (
     _get_request_data,
     _get_url,
 )
-from sentry_sdk.sessions import auto_session_tracking_scope
+from sentry_sdk.sessions import track_session
 from sentry_sdk.tracing import (
     SOURCE_FOR_STYLE,
     TRANSACTION_SOURCE_ROUTE,
@@ -82,7 +82,13 @@ def _looks_like_asgi3(app):
 
 
 class SentryAsgiMiddleware:
-    __slots__ = ("app", "__call__", "transaction_style", "mechanism_type")
+    __slots__ = (
+        "app",
+        "__call__",
+        "transaction_style",
+        "mechanism_type",
+        "span_origin",
+    )
 
     def __init__(
         self,
@@ -90,8 +96,9 @@ class SentryAsgiMiddleware:
         unsafe_context_data=False,
         transaction_style="endpoint",
         mechanism_type="asgi",
+        span_origin="manual",
     ):
-        # type: (Any, bool, str, str) -> None
+        # type: (Any, bool, str, str, str) -> None
         """
         Instrument an ASGI application with Sentry. Provides HTTP/websocket
         data to sent events and basic handling for exceptions bubbling up
@@ -124,6 +131,7 @@ class SentryAsgiMiddleware:
 
         self.transaction_style = transaction_style
         self.mechanism_type = mechanism_type
+        self.span_origin = span_origin
         self.app = app
 
         if _looks_like_asgi3(app):
@@ -161,7 +169,7 @@ class SentryAsgiMiddleware:
         _asgi_middleware_applied.set(True)
         try:
             with sentry_sdk.isolation_scope() as sentry_scope:
-                with auto_session_tracking_scope(sentry_scope, session_mode="request"):
+                with track_session(sentry_scope, session_mode="request"):
                     sentry_scope.clear_breadcrumbs()
                     sentry_scope._name = "asgi"
                     processor = partial(self.event_processor, asgi_scope=scope)
@@ -182,6 +190,7 @@ class SentryAsgiMiddleware:
                             op="{}.server".format(ty),
                             name=transaction_name,
                             source=transaction_source,
+                            origin=self.span_origin,
                         )
                         logger.debug(
                             "[ASGI] Created transaction (continuing trace): %s",
@@ -192,6 +201,7 @@ class SentryAsgiMiddleware:
                             op=OP.HTTP_SERVER,
                             name=transaction_name,
                             source=transaction_source,
+                            origin=self.span_origin,
                         )
                         logger.debug(
                             "[ASGI] Created transaction (new): %s", transaction
@@ -205,7 +215,8 @@ class SentryAsgiMiddleware:
                     )
 
                     with sentry_sdk.start_transaction(
-                        transaction, custom_sampling_context={"asgi_scope": scope}
+                        transaction,
+                        custom_sampling_context={"asgi_scope": scope},
                     ):
                         logger.debug("[ASGI] Started transaction: %s", transaction)
                         try:
