@@ -5,7 +5,6 @@ from django.utils.safestring import mark_safe
 from django import VERSION as DJANGO_VERSION
 
 import sentry_sdk
-from sentry_sdk import Scope
 from sentry_sdk._types import TYPE_CHECKING
 from sentry_sdk.consts import OP
 from sentry_sdk.utils import ensure_integration_enabled
@@ -93,7 +92,7 @@ def patch_templates():
         context = context or {}
         if "sentry_trace_meta" not in context:
             context["sentry_trace_meta"] = mark_safe(
-                Scope.get_current_scope().trace_propagation_meta()
+                sentry_sdk.get_current_scope().trace_propagation_meta()
             )
 
         with sentry_sdk.start_span(
